summaryrefslogtreecommitdiffstats
path: root/jnlib/logging.c
diff options
context:
space:
mode:
Diffstat (limited to 'jnlib/logging.c')
-rw-r--r--jnlib/logging.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/jnlib/logging.c b/jnlib/logging.c
index 97a2b9c9e..c944006a5 100644
--- a/jnlib/logging.c
+++ b/jnlib/logging.c
@@ -87,10 +87,11 @@ struct fun_cookie_s {
char name[1];
};
/* Write NBYTES of BUF to file descriptor FD. */
static int
-writen (int fd, const unsigned char *buf, size_t nbytes)
+writen (int fd, const void *buffer, size_t nbytes)
{
+ const char *buf = buffer;
size_t nleft = nbytes;
int nwritten;
@@ -87,10 +87,11 @@ struct fun_cookie_s {
char name[1];
};
-/* Write NBYTES of BUF to file descriptor FD. */
+/* Write NBYTES of BUFFER to file descriptor FD. */
static int